@@ -1,28 +1,38 @@
 """Admin settings"""
+from django.conf import settings
 from django.contrib import admin
+
+from social.utils import setting_name
 from social.apps.django_app.default.models import UserSocialAuth, Nonce, \
                                                   Association
 
 
-_User = UserSocialAuth.user_model()
-
-username = getattr(_User, 'USERNAME_FIELD', None) or \
-           hasattr(_User, 'username') and 'username' or \
-           None
-fieldnames = ('first_name', 'last_name', 'email', username)
-all_names = _User._meta.get_all_field_names()
-user_search_fields = ['user__' + name for name in fieldnames
-                            if name and name in all_names]
-
-
 class UserSocialAuthOption(admin.ModelAdmin):
     """Social Auth user options"""
     list_display = ('id', 'user', 'provider', 'uid')
-    search_fields = user_search_fields
     list_filter = ('provider',)
     raw_id_fields = ('user',)
     list_select_related = True
 
+    def __init__(self, *args, **kwargs):
+        self.search_fields = self.get_search_fields()
+        super(UserSocialAuthOption, self).__init__(*args, **kwargs)
+
+    def get_search_fields(self):
+        search_fields = getattr(
+            settings, setting_name('ADMIN_USER_SEARCH_FIELDS'), None
+        )
+        if search_fields is None:
+            _User = UserSocialAuth.user_model()
+            username = getattr(_User, 'USERNAME_FIELD', None) or \
+                       hasattr(_User, 'username') and 'username' or \
+                       None
+            fieldnames = ('first_name', 'last_name', 'email', username)
+            all_names = _User._meta.get_all_field_names()
+            search_fields = [name for name in fieldnames
+                                if name and name in all_names]
+        return ['user_' + name for name in search_fields]
+
 
 class NonceOption(admin.ModelAdmin):
     """Nonce options"""
