@@ -38,8 +38,10 @@ class OAuthAuth(BaseAuth):
 
     def get_scope(self):
         """Return list with needed access scope"""
-        return (self.DEFAULT_SCOPE or []) + \
-               self.setting('SCOPE', [])
+        scope = self.setting('SCOPE', [])
+        if not self.setting('IGNORE_DEFAULT_SCOPE', False):
+            scope += self.DEFAULT_SCOPE or []
+        return scope
 
     def get_scope_argument(self):
         param = {}
@@ -119,6 +121,8 @@ class BaseOAuth1(OAuthAuth):
 
     def do_auth(self, access_token, *args, **kwargs):
         """Finish the auth process once the access_token was retrieved"""
+        if not isinstance(access_token, dict):
+            access_token = parse_qs(access_token)
         data = self.user_data(access_token)
         if data is not None and 'access_token' not in data:
             data['access_token'] = access_token
